[−][src]Trait frame_support::storage::IterableStorageMap
A strongly-typed map in storage whose keys and values can be iterated over.
Associated Types
Required methods
fn iter() -> Self::Iterator[−]
Enumerate all elements in the map in no particular order. If you alter the map while doing this, you'll get undefined results.
fn drain() -> Self::Iterator[−]
Remove all elements from the map and iterate through them in no particular order. If you add elements to the map while doing this, you'll get undefined results.
fn translate<O: Decode, F: Fn(K, O) -> Option<V>>(f: F)[−]
Translate the values of all elements by a function f, in the map in no particular order.
By returning None from f for an element, you'll remove it from the map.
Implementors
impl<K: FullCodec, V: FullCodec, G: StorageMap<K, V>> IterableStorageMap<K, V> for G where
G::Hasher: ReversibleStorageHasher, [src][+]
G::Hasher: ReversibleStorageHasher,